Documentation
¶
Index ¶
- func NewMsgServerImpl(keeper Keeper) types.MsgServer
- type Keeper
- func (k Keeper) GetNativeDexAddress(ctx sdk.Context) common.Address
- func (k Keeper) GetParams(ctx sdk.Context) (params types.Params)
- func (k Keeper) GetParamsIfSet(ctx sdk.Context) (params types.Params, err error)
- func (k Keeper) GetVerifiedCrocPolicyAddress(ctx sdk.Context) common.Address
- func (k Keeper) GetWhitelistedContractAddresses(ctx sdk.Context) []string
- func (k Keeper) Logger(ctx sdk.Context) log.Logger
- func (k Keeper) Params(c context.Context, req *types.QueryParamsRequest) (*types.QueryParamsResponse, error)
- func (k Keeper) SetParams(ctx sdk.Context, params types.Params)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewMsgServerImpl ¶
NewMsgServerImpl returns an implementation of the MsgServer interface for the provided Keeper.
Types ¶
type Keeper ¶
func NewKeeper ¶
func NewKeeper( storeKey storetypes.StoreKey, cdc codec.BinaryCodec, ps paramtypes.Subspace, ek types.EVMKeeper, ) Keeper
func (Keeper) GetNativeDexAddress ¶
func (Keeper) GetParams ¶
GetParams will return the current Params Note that if this function is called before the chain has been initalized, a panic will occur. Use GetParamsIfSet instead e.g. in an AnteHandler which may run for creating genesis transactions
func (Keeper) GetParamsIfSet ¶ added in v1.6.1
GetParamsIfSet will return the current params, but will return an error if the chain is still initializing. By error checking this function is safe to use in handling genesis transactions and upgrade handlers.
func (Keeper) GetVerifiedCrocPolicyAddress ¶
func (Keeper) GetWhitelistedContractAddresses ¶ added in v1.6.0
func (Keeper) Params ¶
func (k Keeper) Params(c context.Context, req *types.QueryParamsRequest) (*types.QueryParamsResponse, error)
Click to show internal directories.
Click to hide internal directories.