Documentation
¶
Index ¶
- func ExportGenesis(ctx sdk.Context, k Keeper) types.GenesisState
- func InitGenesis(ctx sdk.Context, k Keeper, data types.GenesisState)
- type Keeper
- func (k Keeper) GetGasFreeMessageTypes(ctx sdk.Context) []string
- func (k Keeper) GetGasFreeMessageTypesSet(ctx sdk.Context) map[string]struct{}
- func (k Keeper) GetGasfreeErc20InteropFeeBasisPoints(ctx sdk.Context) (uint64, error)
- func (k Keeper) GetGasfreeErc20InteropTokens(ctx sdk.Context) ([]string, error)
- func (k Keeper) GetParamsIfSet(ctx sdk.Context) (params types.Params, err error)
- func (k Keeper) IsGasFreeMsg(gasFreeMessageTypes map[string]struct{}, msg sdk.Msg) bool
- func (k Keeper) IsGasFreeMsgType(ctx sdk.Context, msgType string) bool
- func (k Keeper) IsGasFreeTx(ctx sdk.Context, keeper Keeper, tx sdk.Tx) (bool, error)
- func (k Keeper) Params(c context.Context, req *types.QueryParamsRequest) (*types.QueryParamsResponse, error)
- func (k Keeper) SetGasFreeMessageTypes(ctx sdk.Context, gasFreeMessageTypes []string)
- func (k Keeper) SetGasfreeErc20InteropFeeBasisPoints(ctx sdk.Context, feeBasisPoints uint64)
- func (k Keeper) SetGasfreeErc20InteropTokens(ctx sdk.Context, tokens []string)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExportGenesis ¶
func ExportGenesis(ctx sdk.Context, k Keeper) types.GenesisState
ExportGenesis exports all the state needed to restart the chain from the current state of the chain
func InitGenesis ¶
func InitGenesis(ctx sdk.Context, k Keeper, data types.GenesisState)
InitGenesis starts a chain from a genesis state
Types ¶
type Keeper ¶
func NewKeeper ¶
func NewKeeper(cdc codec.Codec, storeKey storetypes.StoreKey, paramSpace paramstypes.Subspace) Keeper
func (Keeper) GetGasFreeMessageTypes ¶
func (Keeper) GetGasFreeMessageTypesSet ¶
func (Keeper) GetGasfreeErc20InteropFeeBasisPoints ¶ added in v1.6.0
GetGasfreeErc20InteropFeeBasisPoints returns the current fee basis points for ERC20 interop operations. If the param is not set yet (e.g. during early chain init), it falls back to the default param value.
func (Keeper) GetGasfreeErc20InteropTokens ¶ added in v1.6.0
GetGasfreeErc20InteropTokens returns the configured list of ERC20 token denoms subject to interop fee logic. Returns default (empty slice) if params not yet initialized.
func (Keeper) GetParamsIfSet ¶
GetParamsIfSet will return the current params, but will return an error if the chain is still initializing. By error checking this function is safe to use in handling genesis transactions.
func (Keeper) IsGasFreeMsg ¶
IsGasFreeMsg checks if the given msg is in the given gasFreeMessageTypes set, and if it shoudl be
func (Keeper) IsGasFreeMsgType ¶
IsGasFreeMsgType checks if the given msgType is one of the GasFreeMessageTypes
func (Keeper) IsGasFreeTx ¶
Checks if the given Tx contains only messages in the GasFreeMessageTypes set
func (Keeper) Params ¶
func (k Keeper) Params(c context.Context, req *types.QueryParamsRequest) (*types.QueryParamsResponse, error)
Params queries the params of the microtx module